@@ -426,7 +426,7 @@ class TranslationSolvers():
             else:
                 probe_loc = np.zeros([1,len(kelong)], dtype=np.int32)
                 probe_vec = np.zeros([1,len(kelong)], dtype=np.int32)
-                warnings.warn('no provided probe vector, using a blank probe'/
+                warnings.warn('no provided probe vector, using a blank probe'\
                               '. This will result in zero sum intensity.')
         else:
             probe_vec = probe_vec
@@ -683,7 +683,7 @@ class TranslationSolvers():
             else:
                 probe_loc = np.zeros([1,len(ke)], dtype=np.int32)
                 probe_vec = np.zeros([1,len(ke)], dtype=np.int32)
-                warnings.warn('no provided probe vector, using a blank probe'/
+                warnings.warn('no provided probe vector, using a blank probe'\
                               '. This will result in zero sum intensity.')
                 
         else:
